import os
import time

import oss2
import requests
import xlrd
import xlwt
from dateutil.relativedelta import relativedelta
from flask import current_app, jsonify, request
from sqlalchemy import and_
import zipfile

from apps.models import *

from apps.models import ProjectManagement
from apps.utils.response_code import RET
from apps.inves_manage import api_manage
from apps.util import verify_token


# 项目管理---项目列表
from apps.inves_manage.siku_view import get_num, upload_daily_picture


"""台账管理"""


# 编辑页文件图片删除接口
def file_delete(file_del_list, project_id):
    try:
        if file_del_list:
            for file_id in file_del_list:
                if file_id:
                    file_obj = ProjectFile.query.filter_by(id=file_id, project_id=project_id, file_type=1).first()
                    db.session.delete(file_obj)
                    db.session.commit()
        return 'ok'
    except Exception as e:
        db.session.rollback()
        current_app.logger.error(e)
        return 'error'


# 获取项目列表
@api_manage.route("/SearchProject1", methods=["POST"])
def search_project1():
    req_dic = request.get_json()

    token = request.headers['token']

    project_stalker = req_dic['project_stalker']

    project_name = req_dic['project_name']
    district = req_dic['district']
    development_area = req_dic['development_area']
    investor_name = req_dic['investor_name']
    investor_district = req_dic['investor_district']
    industry = req_dic['industry']
    investment_volume = req_dic['investment_volume']
    project_progress = req_dic['project_progress']
    project_year = req_dic['project_year']
    page = req_dic['page']
    per_page = req_dic['per_page']

    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")

    try:
        project_obj = ProjectManagement.query.filter(
            and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
                 ProjectManagement.project_stalker == project_stalker if project_stalker else text(''),
                 ProjectManagement.project_name == project_name if project_name else text(''),
                 ProjectManagement.district == district if district else text(''),
                 ProjectManagement.development_area == development_area if development_area else text(''),
                 ProjectManagement.investor_name >= investor_name[0] if investor_name else text(''),
                 ProjectManagement.investor_name < investor_name[1] if investor_name else text(''),
                 ProjectManagement.investor_district == investor_district if investor_district else text(''),
                 ProjectManagement.industry == industry if industry else text(''),
                 ProjectManagement.investment_volume == investment_volume if investment_volume else text(''),
                 ProjectManagement.project_progress == project_progress if project_progress else text(''),
                 ProjectManagement.project_year == project_year if project_year else text(''),
                 ))

        if not project_obj.all():
            return jsonify(code=RET.NODATA, msg='没有符合条件的数据！')
        project_size = project_obj.count()

        project_obj_list = project_obj.order_by(ProjectManagement.upload_time.desc()).paginate(page, per_page).items
        if project_obj_list:
            data = [{
                "id": project_obj.id,
                "project_stalker": project_obj.project_stalker,
                "project_name": project_obj.project_name,
                "district": project_obj.district,
                "development_area": project_obj.development_area,
                "attract_name": project_obj.attract_name,
                "investor_name": project_obj.investor_name,
                "investor_district": project_obj.investor_district,
                "industry": project_obj.industry,
                "investment_volume": project_obj.investment_volume,
                "construction_content": project_obj.construction_content,
                "project_address": project_obj.project_address,
                "project_progress": project_obj.project_progress,
                "project_problem": project_obj.project_problem,
                "project_year": project_obj.project_year
            } for project_obj in project_obj_list]
            return jsonify(code=RET.OK, data={"data": data, "size": project_size, "msg": "数据获取成功！"})

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="查询数据库错误！")


# 项目详情
@api_manage.route("/CheckProjectDetail1", methods=["POST"])
def check_project_detail1():
    req_dic = request.get_json()
    project_id = req_dic['project_id']
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    if not project_id:
        return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
    try:
        project_obj_list = ProjectManagement.query.filter_by(id=project_id)
        data = [{"id": project_obj.id,
                 "project_stalker": project_obj.project_stalker,  # 项目跟踪
                 "project_name": project_obj.project_name,  # 项目名称
                 "district": project_obj.district,  # 项目所在地
                 "development_area": project_obj.development_area,  # 开发区
                 "attract_name": project_obj.attract_name,  # 引资方名称
                 "investor_name": project_obj.investor_name,  # 投资方名称(万元)
                 "investor_district": project_obj.investor_district,  # 投资方所在地(亩)
                 "industry": project_obj.industry,  # 所属行业
                 "investment_volume": project_obj.investment_volume,  # 总投资额(万元)
                 "construction_content": project_obj.construction_content,  # 建设内容
                 "project_address": project_obj.project_address,  # 项目选址
                 "project_progress": project_obj.project_progress,  # 项目进展
                 "project_problem": project_obj.project_problem,  # 难点情况
                 "project_year": project_obj.project_year,  # 项目年份
                 "upload_unity": project_obj.upload_unity,  # 上传部门
                 "upload_people": project_obj.upload_people,  # 上传人
                 "upload_time": project_obj.upload_time,  # 上传时间
                 "project_num": project_obj.project_num,  # 项目编号
                 "project_source": project_obj.project_source,  # 项目来源
                 "project_unity": project_obj.project_unity,  # 项目申报单位
                 "is_development_project": project_obj.is_development_project,  # 是否属于开发区项目
                 "sign_time": project_obj.sign_time,  # 签约时间
                 "start_time": project_obj.start_time,  # 开工时间
                 "end_time": project_obj.end_time,  # 竣工时间
                 "investor_rank": project_obj.investor_rank,  # 投资方排名
                 "is_transf_project": project_obj.is_transf_project,  # 是否转型项目
                 "country": project_obj.country,  # 投资方国别
                 "provence": project_obj.provence,  # 投资方省份
                 "city": project_obj.city,  # 投资方市
                 "job_num": project_obj.job_num,  # 带动就业岗位（个）
                 "new_value": project_obj.new_value,  # 新增产值（亿元）
                 "revenue": project_obj.revenue,  # 贡献税收（亿元）
                 "use_land": project_obj.use_land,  # 项目用地情况（亩）
                 "new_land": project_obj.new_land,  # 其中新增用地（亩）
                 "construction_nature": project_obj.construction_nature,  # 建设性质（亩）
                 "is_fixed_investment": project_obj.is_fixed_investment,  # 固定资产投资项目
                 "investment_year": project_obj.investment_year,  # 资金到位本年累计（万元）
                 "investment_history": project_obj.investment_history,  # 资金到位历史累计（万元）
                 "cooperation_way": project_obj.cooperation_way,  # 合作方式
                 "set_project_status": project_obj.set_project_status,  # 项目立项状态
                 "investor_people": project_obj.investor_people,  # 投资方联系人
                 "investor_mobile": project_obj.investor_mobile,  # 投资方电话
                 "investor_address": project_obj.investor_address,  # 投资方联系地址
                 } for project_obj in project_obj_list]
        return jsonify(code=RET.OK, data={"data": data, "msg": "数据获取成功！"})
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="操作失败！数据库查询错误")


# 下载模板
@api_manage.route("/DownloadProjectTemplate", methods=["POST"])
def download_project_template():
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    project_template = "http://39.100.39.50:8008/aaa_statics/template_file/招商引资项目表.xlsx"
    return jsonify(code=RET.OK, data=project_template, msg="模板下载成功！")


# 批量导入
@api_manage.route("/UploadProjectData2", methods=["POST"])
def upload_project_data2():
    # 获取上传的文件
    token = request.headers['token']
    action_name = '批量导入'

    token = request.headers['token']
    try:
        user_obj = verify_token(token)
        user_name = user_obj.real_name
        user_unity = user_obj.belong_organization
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    # 上传的文件
    file = request.files['file']
    print(file.filename)  # 打印文件名

    try:
        f = file.read()  # 文件内容
        data = xlrd.open_workbook(file_contents=f)
        table = data.sheets()[0]
        names = data.sheet_names()  # 返回book中所有工作表的名字
        status = data.sheet_loaded(names[0])  # 检查sheet1是否导入完毕
        print(status)
        nrows = table.nrows  # 获取该sheet中的有效行数
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.THIRDERR, msg="读取文件失败！")

    rep_num = 0
    rep_project_name_list = []
    success_num = 0
    name = ''

    row_list = [table.row_values(i) for i in range(4, nrows)]
    for i in range(0, len(row_list)):
        row_content = row_list[i]
        if not row_content:
            return jsonify(code=RET.NODATA,
                           msg="表格内无有效数据！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。(注：第三行为首行有效数据不能为空、第一行和第二行无法读取。)")
        # del (row_content[0])
        project_name = row_content[1]  # 项目名称
        # 判断该项目是否已经存在
        project_obj = ProjectManagement.query.filter_by(project_name=project_name).first()
        if project_obj:
            rep_num += 1
            rep_project_name_list.append(project_name)
            continue
        try:
            project_name = row_content[1]  # 项目名称
            district = row_content[2]  # 项目所在地
            development_area = row_content[3]  # 开发区
            attract_name = row_content[4]  # 引资方名称
            investor_name = row_content[5]  # 投资方名称
            country = row_content[6]  # 投资方国别
            provence = row_content[7]  # 投资方省份
            city = row_content[8]  # 投资方市
            industry1 = row_content[9]  # 所属行业1
            industry2 = row_content[10]  # 所属行业2
            investment_volume = row_content[11]  # 总投资额(万元)
            construction_content = row_content[12]  # 建设内容
            construction_nature = row_content[13]  # 建设性质（亩）
            project_address = row_content[14]  # 项目选址
            use_land = row_content[15]  # 项目用地情况（亩）
            new_land = row_content[16]  # 其中新增用地（亩）
            set_project_status = row_content[17]  # 项目立项状态
            project_progress = row_content[18]  # 项目进展
            sign_time = row_content[19]  # 签约时间
            start_time = row_content[20]  # 开工时间
            end_time = row_content[21]  # 竣工时间
            is_fixed_investment = row_content[22]  # 固定资产投资项目
            investment_year = row_content[23]  # 资金到位本年累计（万元）
            investment_history = row_content[24]  # 资金到位历史累计（万元）
            project_stalker = row_content[25]  # 项目跟踪
            project_stalker_explain = row_content[26]  # 项目跟踪说明
        except Exception as e:
            # 表示操作失败，回滚数据库操作
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据异常！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。")

        if not project_name:
            return jsonify(code=RET.PARAMERR, msg='项目名称不能为空！')

        project_obj_list = ProjectManagement.query.all()  # 项目编号
        time_strf = datetime.now().strftime("%Y%m%d")
        max_project_num = ''
        if project_obj_list:
            max_project_num = max([project_obj.project_num for project_obj in project_obj_list])
        if max_project_num:
            max_project_num = max_project_num[8:]
            num = get_num(max_project_num)
            if num == 'error':
                # return jsonify(code=RET.DATAERR, msg='编号超出三位的规定范围，请联系管理员')
                return 'error'
            project_num = time_strf + num
        else:
            project_num = time_strf + '001'
        try:
            # 写入数据库
            file_time = datetime.now().strftime("%Y-%m-%d %H:%M")
            project_obj = ProjectManagement(
                project_num=project_num,
                project_name=project_name,
                district=district,
                development_area=development_area,
                attract_name=attract_name,
                investor_name=investor_name,
                country=country,
                provence=provence,
                city=city,
                industry=industry1 + '/' + industry2,
                investment_volume=investment_volume,
                construction_content=construction_content,
                construction_nature=construction_nature,
                project_address=project_address,
                use_land=use_land,
                new_land=new_land,
                set_project_status=set_project_status,
                project_progress=project_progress,
                sign_time=sign_time,
                start_time=start_time,
                end_time=end_time,
                is_fixed_investment=is_fixed_investment,
                investment_year=investment_year,
                investment_history=investment_history,
                project_stalker=project_stalker,
                project_stalker_explain=project_stalker_explain,
                upload_unity=user_unity,
                upload_people=user_name,
                upload_time=file_time,
            )
            db.session.add(project_obj)
            db.session.commit()
            success_num += 1
            continue
        except Exception as e:
            # 表示操作失败，回滚数据库操作
            db.session.rollback()
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库异常")

    if success_num > 0:
        return jsonify(code=RET.OK,
                       msg='上传成功！数据上传 {} 条数据'.format(success_num))
    else:
        return jsonify(code=RET.DATAERR, msg='无新数据上传。')


# 批量导出
@api_manage.route("/BatchExportProject5", methods=["POST"])
def batch_export_project5():
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")


    req_dic = request.get_json()
    select_id_list = req_dic["select_id_list"]
    path = './apps/statics/project_file/'
    # pro_path = 'http://39.100.39.50:8008/aaa_statics/project_file/'  # 项目路径
    pro_path = 'http://192.168.1.4:5000/statics/project_file/'  # 项目路径
    if not select_id_list:
        return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
    target_data_list = []
    for select_id in select_id_list:
        try:
            project_obj = ProjectManagement.query.filter_by(id=select_id).first()
            # 提取数据，写入xslx表格
            data_list = []
            project_num = project_obj.project_num
            data_list.append(project_num)
            project_name = project_obj.project_name
            data_list.append(project_name)
            district = project_obj.district
            data_list.append(district)
            development_area = project_obj.development_area
            data_list.append(development_area)
            attract_name = project_obj.attract_name
            data_list.append(attract_name)
            investor_name = project_obj.investor_name
            data_list.append(investor_name)
            investor_district = project_obj.investor_district
            data_list.append(investor_district)
            country = project_obj.country
            data_list.append(country)
            provence = project_obj.provence
            data_list.append(provence)
            city = project_obj.city
            data_list.append(city)
            industry = project_obj.industry
            data_list.append(industry)
            # industry2 = project_obj.industry2
            # data_list.append(industry2)
            investment_volume = project_obj.investment_volume
            data_list.append(investment_volume)
            construction_content = project_obj.construction_content
            data_list.append(construction_content)
            construction_nature = project_obj.construction_nature
            data_list.append(construction_nature)
            project_address = project_obj.project_address
            data_list.append(project_address)
            use_land = project_obj.use_land
            data_list.append(use_land)
            new_land = project_obj.new_land
            data_list.append(new_land)
            set_project_status = project_obj.set_project_status
            data_list.append(set_project_status)
            project_progress = project_obj.project_progress
            data_list.append(project_progress)
            sign_time = project_obj.sign_time
            data_list.append(sign_time)
            start_time = project_obj.start_time
            data_list.append(start_time)
            end_time = project_obj.end_time
            data_list.append(end_time)
            is_fixed_investment = project_obj.is_fixed_investment
            data_list.append(is_fixed_investment)
            investment_year = project_obj.investment_year
            data_list.append(investment_year)
            investment_history = project_obj.investment_history
            data_list.append(investment_history)
            project_stalker = project_obj.project_stalker
            data_list.append(project_stalker)
            project_stalker_explain = project_obj.project_stalker_explain
            data_list.append(project_stalker_explain)
            target_data_list.append(data_list)
        except Exception as e:
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库查询错误！")
    head_list = ''
    sheet = ''
    try:
        sheet_name_titles = {
            "sheet1": ["项目编号", "项目名称", "项目所在地", "所属开发区", "引资方名称", "投资方名称",
                       "国别（地区）", "省（自治区、直辖市、特别行政区）",
                       "市（州、盟、区）", "所属行业", "总投资额（万元）", "项目建设内容", "项目建设性质",
                       "项目选址详情", "用地情况（亩）", "其中新增用地（亩）", "项目立项情况", "项目进展", "签约时间",
                       "开工时间", "竣工时间", "固资产投资项目（是、否）", "资金到位本年累计（万元）",
                       "资金到位历史累计（万元）", "项目跟踪", "项目跟踪说明",

                       ]}

        excel = xlwt.Workbook(encoding='utf-8')
        # 写入表头
        for i in range(len(sheet_name_titles)):
            for k, v in sheet_name_titles.items():
                sheet_name = k
                sheet = excel.add_sheet(sheet_name)
                head_list = v
                print(head_list)
                for j in range(len(head_list)):
                    sheet.write(0, j, head_list[j])
        # 写入数据，从第二行(i+1)
        rows = len(target_data_list)
        cols = len(head_list)
        for i in range(rows):
            for j in range(cols):
                sheet.write(i + 1, j, target_data_list[i][j])
        time_stamp = '{0:%Y%m%d%H%M%S}'.format(datetime.now())
        file_name = "招商引资项目表{}.xlsx".format(time_stamp)
        excel.save(path + file_name)
        return jsonify(code=RET.OK, url=pro_path + file_name, msg="导出/下载成功！")
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="批量导出操作失败！")


# 批量删除（逻辑删除）
@api_manage.route("/BatchDelete1", methods=["POST"])
def batch_delete1():
    req_dic = request.get_json()
    token = request.headers['token']

    try:
        user_obj = verify_token(token)
        user_name = user_obj.real_name
        # user_id = user_obj.id
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行批量删除操作时用户信息校验失败，请重新登陆后尝试！")

    delete_id_list = req_dic["delete_id_list"]
    if not delete_id_list:
        return jsonify(code=RET.PARAMERR, msg="参数不能为空！")

    try:
        for select_id in delete_id_list:
            project_obj_list = ProjectManagement.query.filter_by(id=select_id).all()
            if not project_obj_list:
                return jsonify(code=RET.DBERR, msg="数据不存在！")
            for project_obj in project_obj_list:
                project_obj.is_delete = 1
                db.session.commit()
        return jsonify(code=RET.OK, msg="删除成功！")
    except Exception as e:
        db.session.rollback()
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="批量删除操作失败！")


# # 项目详情信息/编辑页的数据展示
# @api_manage.route("/CheckProjectDetail2", methods=["POST"])
# def check_project_detail2():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     token = request.headers['token']
#     # year = str(datetime.now().year)
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         # project_num = project_obj1.project_num
#         # # 先查找本年份的，确保是最新的项目信息。如果没有本年的就用往年的
#         # project_obj2 = ProjectManagement.query.filter(
#         #     ProjectManagement.project_num == project_num,
#         #     ProjectManagement.upload_time.like('%{}%'.format(year))
#         # ).first()
#         # if project_obj2:
#         #     project_obj = project_obj2
#         #     project_id = project_obj2.id
#         # else:
#         #     project_obj = project_obj1
#         project_data = {"project_stalker": project_obj.project_stalker,
#                         "project_name": project_obj.project_name,
#                         "district": project_obj.district,
#                         "development_area": project_obj.development_area,
#                         "attract_name": project_obj.attract_name,
#                         "investor_name": project_obj.investor_name,
#                         "industry": project_obj.industry,
#                         "investment_volume": project_obj.investment_volume,
#                         "construction_content": project_obj.construction_content,
#                         "project_address": project_obj.project_address,
#                         "project_progress": project_obj.project_progress,
#                         "project_problem": project_obj.project_problem,
#                         "upload_unity": project_obj.upload_unity,
#                         "upload_people": project_obj.upload_people,
#                         "upload_time": project_obj.upload_time,
#                         "project_num": project_obj.project_num,
#                         "project_source": project_obj.project_source,
#                         "project_unity": project_obj.project_unity,
#                         "is_development_project": project_obj.is_development_project,
#                         "sign_time": project_obj.sign_time,
#                         "start_time": project_obj.start_time,
#                         "end_time": project_obj.end_time,
#                         "investor_rank": project_obj.investor_rank,
#                         "is_transf_project": project_obj.is_transf_project,
#                         "country": project_obj.country,
#                         "provence": project_obj.provence,
#                         "city": project_obj.city,
#                         "job_num": project_obj.job_num,
#                         "new_value": project_obj.new_value,
#                         "revenue": project_obj.revenue,
#                         "use_land": project_obj.use_land,
#                         "new_land": project_obj.new_land,
#                         "construction_nature": project_obj.construction_nature,
#                         "is_fixed_investment": project_obj.is_fixed_investment,
#                         "investment_year": project_obj.investment_year,
#
#                         "investment_history": project_obj.investment_history,
#                         "cooperation_way": project_obj.cooperation_way,
#                         "set_project_status": project_obj.set_project_status,
#                         "investor_people": project_obj.investor_people,
#                         "investor_mobile": project_obj.investor_mobile,
#                         "investor_address": project_obj.investor_address,
#                         }
#         file_obj_list = ProjectFile.query.filter_by(project_id=project_id, file_type=1, flag=5).all()
#         file_data = []
#         if file_obj_list:
#             file_data = [{
#                 "id": file_obj.id,
#                 "file_url": file_obj.file_url,
#                 "file_name": file_obj.file_name,
#                 "project_id": file_obj.project_id,
#                 "file_type": file_obj.file_type
#             } for file_obj in file_obj_list]
#
#         return jsonify(code=RET.OK, data={"project_data": project_data,
#                                           "file_data": file_data,
#                                           "msg": "数据获取成功！"})
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="操作失败！数据库查询错误")


# 项目编辑
@api_manage.route("/ProjectEdit1", methods=["POST"])
def project_edit():
    file_list = request.files.getlist('file_list')
    file_del_list = request.form.getlist('file_del_list')

    project_stalker = request.form['project_stalker']
    project_name = request.form['project_name']
    district = request.form['district']
    development_area = request.form['development_area']
    attract_name = request.form['attract_name']
    investor_name = request.form['investor_name']
    industry = request.form['industry']
    investment_volume = request.form['investment_volume']
    construction_content = request.form['construction_content']
    project_address = request.form['project_address']
    project_progress = request.form['project_progress']
    project_problem = request.form['project_problem']
    upload_unity = request.form['upload_unity']
    upload_people = request.form['upload_people']
    upload_time = request.form['upload_time']
    project_num = request.form['project_num']
    project_source = request.form['project_source']
    project_unity = request.form['project_unity']
    is_development_project = request.form['is_development_project']
    sign_time = request.form['sign_time']
    start_time = request.form['start_time']
    end_time = request.form['end_time']
    investor_rank = request.form['investor_rank']
    is_transf_project = request.form['is_transf_project']
    country = request.form['country']
    provence = request.form['provence']
    city = request.form['city']
    job_num = request.form['job_num']
    new_value = request.form['new_value']
    revenue = request.form['revenue']
    use_land = request.form['use_land']
    new_land = request.form['new_land']
    construction_nature = request.form['construction_nature']
    is_fixed_investment = request.form['is_fixed_investment']
    investment_year = request.form['investment_year']
    investment_history = request.form['investment_history']
    cooperation_way = request.form['cooperation_way']
    set_project_status = request.form['set_project_status']
    investor_people = request.form['investor_people']
    investor_mobile = request.form['investor_mobile']
    investor_address = request.form['investor_address']
    project_id = request.form['project_id']

    token = request.headers['token']

    edit_time = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    flag = 0  # 记录是否更新了最新进展、待解决问题
    try:
        user_obj = verify_token(token)
        user_name = user_obj.real_name
        user_id = user_obj.id
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行编辑项目信息操作时用户信息校验失败，请重新登陆后尝试！")
    try:
        project_obj = ProjectManagement.query.get(project_id)
        if not project_obj:
            return jsonify(code=RET.NODATA, msg='查无此项目！')
        project_obj.project_stalker = project_stalker
        project_obj.project_name = project_name
        project_obj.district = district
        project_obj.development_area = development_area
        project_obj.attract_name = attract_name
        project_obj.investor_name = investor_name
        project_obj.industry = industry
        project_obj.investment_volume = investment_volume
        project_obj.construction_content = construction_content
        project_obj.project_address = project_address
        project_obj.project_progress = project_progress
        project_obj.project_problem = project_problem
        project_obj.upload_unity = upload_unity
        project_obj.upload_people = upload_people
        project_obj.upload_time = upload_time
        project_obj.project_num = project_num
        project_obj.project_source = project_source
        project_obj.project_unity = project_unity
        project_obj.is_development_project = is_development_project
        project_obj.sign_time = sign_time
        project_obj.start_time = start_time
        project_obj.end_time = end_time
        project_obj.investor_rank = investor_rank
        project_obj.is_transf_project = is_transf_project
        project_obj.country = country
        project_obj.provence = provence
        project_obj.city = city
        project_obj.job_num = job_num
        project_obj.new_value = new_value
        project_obj.revenue = revenue
        project_obj.use_land = use_land
        project_obj.new_land = new_land
        project_obj.construction_nature = construction_nature
        project_obj.is_fixed_investment = is_fixed_investment
        project_obj.investment_year = investment_year
        project_obj.investment_history = investment_history
        project_obj.cooperation_way = cooperation_way
        project_obj.set_project_status = set_project_status
        project_obj.investor_people = investor_people
        project_obj.investor_mobile = investor_mobile
        project_obj.investor_address = investor_address
        db.session.commit()
        # 删除文件和图片
        result = file_delete(file_del_list, project_id)
        if result == 'error':
            return jsonify(code=RET.DBERR, msg="附件删除异常！")

        try:
            # 上传文件
            if file_list:
                for file_obj in file_list:
                    file_name = file_obj.filename
                    file_url = upload_daily_picture(1, file_name, file_obj)

                    # 存入数据库
                    file_obj = ProjectFile(flag=5,
                                        file_type=1,
                                        file_url=file_url,
                                        file_name=file_name,
                                        upload_time=upload_time,
                                        upload_people=upload_people,
                                        upload_people_id=user_id,
                                        project_id=project_id
                                            )
                    db.session.add(file_obj)
                    db.session.commit()
        except Exception as e:
                current_app.logger.error(e)
                return jsonify(code=RET.DBERR, msg="文件上传失败！")

        return jsonify(code=RET.OK, msg="修改成功！")
    except Exception as e:
        db.session.rollback()
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="查询数据库错误！")


